==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada sauvagardada dins @archive@. Podètz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'dau vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Aquela opcion vos permete de sauvagardar lo contengut de la basa dins un fichier que serà servat dins lo repertòri @dossier@.
Non oblidetz nimai de recuperar l’integralitat dau repertòri <i>IMG/</i>, que conten lu imatges e lu documents utilizats dins lu articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquela sauvagarda si porrà restaurar BASTA dins un sit installat emb la meteissa version d’SPIP. Doncas sobretot non cau "vuar la basa" en esperant de reïnstallar la sauvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela opcion vos permete de restaurar una sauvagarda 
 de la basa que l’aviatz facha avans. Per aquò faire, cau aver botat lo fichier que conten la sauvagarda 
dins lo repertòri @dossier@.
  Totun, sigatz prudent(a) emb aquela foncionalitat: <b>li modificacions e pèrdas eventuali son
  irreversibli.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa'
);

==> spip_4.4.8+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada sauvagardada dins @archive@. Podètz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'dau vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Aquela opcion vos permete de sauvagardar lo contengut de la basa dins un fichier que serà servat dins lo repertòri @dossier@.
Non oblidetz nimai de recuperar l’integralitat dau repertòri <i>IMG/</i>, que conten lu imatges e lu documents utilizats dins lu articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquela sauvagarda si porrà restaurar BASTA dins un sit installat emb la meteissa version d’SPIP. Doncas sobretot non cau "vuar la basa" en esperant de reïnstallar la sauvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela opcion vos permete de restaurar una sauvagarda 
 de la basa que l’aviatz facha avans. Per aquò faire, cau aver botat lo fichier que conten la sauvagarda 
dins lo repertòri @dossier@.
  Totun, sigatz prudent(a) emb aquela foncionalitat: <b>li modificacions e pèrdas eventuali son
  irreversibli.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa',
];
